Learn R Programming

swfscMisc (version 1.1)

das.merge.acoustic: Merge DAS Data Into Acoustic Detections

Description

Fill in sighting information for acoustic detections from DAS file.

Usage

das.merge.acoustic(acoust.file, das.file, out.file)

Arguments

acoust.file
filename of a .csv file of acoustic detections exported from Access database.
das.file
filename of a DAS file.
out.file
desired output .csv filename.