Learn R Programming

swfscMisc (version 1.7.6)

distSmry: Distribution summary

Description

Summarize a numerical distribution.

Usage

distSmry(x, p = 0.95, ...)

Arguments

x

vector of numerical values.

p

percent of distribution to summarized by quantile interval (ci) and highest posterior density interval (hdi).

...

arguments passed on to density to estimate the mode.

Author

Eric Archer [email protected]