Learn R Programming

swfscMisc (version 1.7.6)

perpPoint: Perpendicular Point

Description

Compute the perpendicular point between points and a line specified by an intercept and slope.

Usage

perpPoint(pts, line)

Arguments

pts

two column matrix of points.

line

two element vector giving intercept and slope of a line.

Author

Eric Archer [email protected]